@@ -1,4 +1,4 @@
-# meu_tabplot_lib.py
+# tableplot_lib.py
 
 # Necessary imports for binning and plotting functions
 import pandas as pd
@@ -38,14 +38,16 @@ def simulate_tabplot_binning(df, nbins=100, sort_col=None, decreasing=True, max_
     if df.empty:
         raise ValueError("Empty DataFrame. No data to process.")
 
-    # Adjust: If sort_col is None, try to use the first numeric column.
+    # If sort_col is None, try to use the first numeric column.
     # If 'ID_Cliente' is present and numeric, prioritize it as default.
     if sort_col is None:
-        if 'ID_Cliente' in df.columns and pd.api.types.is_numeric_dtype(df['ID_Cliente']):
-            sort_col = 'ID_Cliente'
+        if 'ID_Client' in df.columns and pd.api.types.is_numeric_dtype(df['ID_Client']):
+            sort_col = 'ID_Client'
         else:
             numeric_cols = df.select_dtypes(include=np.number).columns.tolist()
             sort_col = numeric_cols[0] if numeric_cols else df.columns[0]
+            print(f"Warning: No specific sort column provided or found, using '{sort_col}' for sorting.")
+
 
     if sort_col not in df.columns:
         raise ValueError(f"Sort column '{sort_col}' not found in DataFrame.")
@@ -84,7 +86,7 @@ def simulate_tabplot_binning(df, nbins=100, sort_col=None, decreasing=True, max_
 
     binned_data = {}
 
-    for col_name in df.columns: # Iterate over columns of the original df
+    for col_name in df.columns: # Iterate over columns of the original df (which are already filtered by tableplot)
         is_categorical = isinstance(df_sorted[col_name].dtype, pd.CategoricalDtype) or df_sorted[col_name].dtype == 'object'
 
         if col_name not in df_sorted.columns: # Check if column exists in df_sorted after sorting/binning
@@ -127,7 +129,7 @@ def simulate_tabplot_binning(df, nbins=100, sort_col=None, decreasing=True, max_
                 f"Bin: {bin_idx}<br>"
                 f"Mean {col_name}: {mean_values[bin_idx]:.2f}<br>"
                 f"Median {col_name}: {median_values[bin_idx]:.2f}<br>"
-                f"Standard Deviation {std_values[bin_idx]:.2f}<br>" # Corrected here
+                f"Standard Deviation {std_values[bin_idx]:.2f}<br>"
                 f"Completeness: {completeness[bin_idx]:.2f}%"
                 for bin_idx in range(actual_nbins)
             ]
@@ -154,11 +156,11 @@ def simulate_tabplot_binning(df, nbins=100, sort_col=None, decreasing=True, max_
             current_categories = value_counts_per_bin.columns.tolist()
             if len(current_categories) > max_levels:
                 top_categories = df_sorted[col_name].value_counts().nlargest(max_levels - 1).index.tolist()
-                value_counts_per_bin['Outros'] = value_counts_per_bin.apply(
+                value_counts_per_bin['Others'] = value_counts_per_bin.apply(
                     lambda row: row[[c for c in current_categories if c not in top_categories]].sum(), axis=1
                 )
-                value_counts_per_bin = value_counts_per_bin[top_categories + ['Outros']]
-                current_categories = top_categories + ['Outros']
+                value_counts_per_bin = value_counts_per_bin[top_categories + ['Others']]
+                current_categories = top_categories + ['Others']
 
             missing_counts_per_bin = df_sorted.groupby('bin')[col_name].apply(lambda x: x.isna().sum())
             total_per_bin = df_sorted.groupby('bin').size()
@@ -478,63 +480,50 @@ def plot_tabplot_interactive(binned_data, title="Dynamic Tableplot"):
     fig.show()
 
 
-# --- PART 3: New tableplot function for simplified use ---
-def tableplot(df, sort_by="*", nbins=100, decreasing=True, max_levels=50, title="My 'tableplot' Package in Action!"):
+# --- PART 3: New tableplot function with specified signature ---
+def tableplot(df, cols, sort_col, ascending=False, nbins=100, max_levels=50, title="My Tableplot"):
     """
-    Simplified function to generate an interactive tableplot.
+    Generates an interactive tableplot from a DataFrame with specified columns.
     
     Arguments:
         df (pd.DataFrame): Input table.
-        sort_by (str): Column name for sorting, or "*" for auto-detection,
-                       or None to use the first numeric column (or 'ID_Cliente' if present).
+        cols (list): A list of column names to include in the plot.
+        sort_col (str): The column name to sort the data by.
+        ascending (bool): If True, sorts in ascending order; False for descending.
         nbins (int): Number of bins (groups).
-        decreasing (bool): If True, sorts from largest to smallest.
-        max_levels (int): Maximum number of unique categories to show.
+        max_levels (int): Maximum number of unique categories to show for categorical columns.
         title (str): Plot title.
     """
-    df_copy = df.copy() # Create a copy to avoid modifying the original DataFrame
-    sort_col = None
+    if not isinstance(cols, list) or not all(isinstance(c, str) for c in cols):
+        raise TypeError("The 'cols' argument must be a list of column names (strings).")
+    
+    if sort_col not in df.columns:
+        raise ValueError(f"The 'sort_col' '{sort_col}' was not found in the DataFrame.")
+    
+    # Check if all specified 'cols' exist in the DataFrame
+    missing_cols = [col for col in cols if col not in df.columns]
+    if missing_cols:
+        raise ValueError(f"The following columns in 'cols' were not found in the DataFrame: {missing_cols}")
 
-    # 🔍 Detect column with *Name+ or *Name-
-    special_col = [col for col in df_copy.columns if isinstance(col, str) and col.startswith("*")]
+    # Filter the DataFrame to include only the specified columns and the sort_col
+    # Ensure sort_col is present even if not explicitly in 'cols' for plotting
+    all_relevant_cols = list(set(cols + [sort_col]))
+    df_filtered = df[all_relevant_cols].copy()
 
-    if special_col:
-        raw_col = special_col[0]
-        col_clean = raw_col.strip("*").strip("+").strip("-")
-        sort_col = col_clean
+    # Determine 'decreasing' based on 'ascending' for the binning function
+    decreasing = not ascending
 
-        if raw_col.endswith("+"):
-            decreasing = False
-        elif raw_col.endswith("-"):
-            decreasing = True
-        else:
-            decreasing = True  # default
-
-        df_copy.rename(columns={raw_col: col_clean}, inplace=True)
-
-    elif sort_by == "*":
-        # If '*' is passed and no special column is found, use default logic
-        # (first numeric, or 'ID_Cliente' if present and numeric)
-        if 'ID_Cliente' in df_copy.columns and pd.api.types.is_numeric_dtype(df_copy['ID_Cliente']):
-            sort_col = 'ID_Cliente'
-        else:
-            numeric_cols = df_copy.select_dtypes(include="number").columns.tolist()
-            sort_col = numeric_cols[0] if numeric_cols else df_copy.columns[0] # Fallback to the first column
-        
-        print(f"Sort_by='*' detected '{sort_col}' as default sort column.")
-
-    elif sort_by is not None and sort_by in df_copy.columns:
-        sort_col = sort_by
-    else:
-        # If sort_by is not '*', not a valid column name, or is None, 
-        # it will fall back to simulate_tabplot_binning's default logic for sort_col=None
-        sort_col = None
-        print(f"Sort column '{sort_by}' not found or is invalid. Using default detection.")
-
-
-    # 🧠 Generate binned data and plot
+    # Generate binned data and plot
     binned_data, _, _ = simulate_tabplot_binning(
-        df_copy, nbins=nbins, sort_col=sort_col, decreasing=decreasing, max_levels=max_levels
+        df_filtered, nbins=nbins, sort_col=sort_col, decreasing=decreasing, max_levels=max_levels
     )
 
-    plot_tabplot_interactive(binned_data, title=title)
\ No newline at end of file
+    plot_tabplot_interactive(binned_data, title=title)
+
+
+
+
+
+
+
+
